==> ath1121501.db_2.0.2.tar.gz: ath1121501.db/man/ath1121501_dbconn.Rd <==
\name{ath1121501_dbconn}

\alias{ath1121501_dbconn}
\alias{ath1121501_dbfile}
\alias{ath1121501_dbschema}
\alias{ath1121501_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  ath1121501_dbconn()
  ath1121501_dbfile()
  ath1121501_dbschema(file="", show.indices=FALSE)
  ath1121501_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{ath1121501_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{ath1121501_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{ath1121501_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{ath1121501_dbschema} prints the schema definition of the
  package annotation DB.

  \code{ath1121501_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{ath1121501_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{ath1121501_dbfile}: a character string with the path to the
  package annotation DB.

  \code{ath1121501_dbschema}: none (invisible \code{NULL}).

  \code{ath1121501_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(ath1121501_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by ath1121501_dbconn() was created with:
  dbConnect(SQLite(), dbname=ath1121501_dbfile(), cache_size=64000, synchronous=0)

  ath1121501_dbschema()

  ath1121501_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> ath1121501.db_2.3.5.tar.gz: ath1121501.db/man/ath1121501_dbconn.Rd <==

\name{ath1121501_dbconn}

\alias{ath1121501_dbconn}
\alias{ath1121501_dbfile}
\alias{ath1121501_dbschema}
\alias{ath1121501_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  ath1121501_dbconn()
  ath1121501_dbfile()
  ath1121501_dbschema(file="", show.indices=FALSE)
  ath1121501_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{ath1121501_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{ath1121501_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{ath1121501_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{ath1121501_dbschema} prints the schema definition of the
  package annotation DB.

  \code{ath1121501_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{ath1121501_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{ath1121501_dbfile}: a character string with the path to the
  package annotation DB.

  \code{ath1121501_dbschema}: none (invisible \code{NULL}).

  \code{ath1121501_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(ath1121501_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by ath1121501_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=ath1121501_dbfile(), cache_size=64000,
  synchronous=0)

  ath1121501_dbschema()

  ath1121501_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
